<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="85"/>
        <source>Enter the number to configure: </source>
        <translation>Zadajte číslo na nastavenie: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="90"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="18"/>
        <source>Loading packages...</source>
        <translation>Načítavanie balíčkov...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="19"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 načítaných</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="22"/>
        <source>Initializing...</source>
        <translation>Inicializácia...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="18"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="118"/>
        <source>Package Installer</source>
        <translation>Správca balíčkov</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="128"/>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="695"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="819"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Inštalácia iných balíčkov... Prosím, otvorte to neskôr.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="700"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Parsovanie zlyhalo: v manifestovom súbore sa našlo neplatné štruktúr</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="702"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Parsovanie zlyhalo: v manifestovom súbore sa našlo neplatné číslo verzie!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="704"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>Nie sú nájdené žiadne deb balíčky. Prosím, skontrolujte priečinok.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="842"/>
        <source>The %1 package may be broken</source>
        <translation>Balíčok %1 môže byť poškodený</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="851"/>
        <source>You can only install local %1 packages</source>
        <translation>Môžete inštalovať len lokálne %1 balíčky</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="860"/>
        <source>No permission to access this folder</source>
        <translation>Žiadna oprávnenie na prístup do tohto priečinku</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="877"/>
        <source>Already Added</source>
        <translation>Už pridaný</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="886"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 neexistuje, prosím, zvoľte znovu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="445"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="894"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="1047"/>
        <source>Bulk Install</source>
        <translation>Hromadná inštalácia</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Inštalácia zlyhala, skontrolujte pripojenie k sieti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>Inštalácia zlyhala, prosím, skontrolujte aktualizácie v Štandardnom centrále</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="133"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Inštalácia zlyhala, nedostatočné miesto na disku</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="139"/>
        <source>No digital signature</source>
        <translation>Žiadna digitálna podpis</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="144"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
        <source>Invalid digital signature</source>
        <translation>Neplatný digitálny podpis</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="152"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="880"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1981"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>Administrátor nastavil politiky, ktoré zabraňujú inštalácii tohto balíčka</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="159"/>
        <source>Installation Failed</source>
        <translation>Inštalácia zlyhala</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="863"/>
        <source>current system</source>
        <translation>súčasný systém</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="866"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation> %2 je nainštalovaný v %1, prosím, odstanovte tento balíčok pred inštaláciou</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="873"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>Nerovnajúce sa závislosti, skúste inštalovať aplikáciu v režime kompatibility</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="876"/>
        <source>Compatibility mode installation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
        <source>Failed to install %1</source>
        <translation>Nepodarilo sa inštalovať %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1328"/>
        <source>Unable to install - no digital signature</source>
        <translation>Nepodarilo sa inštalovať – žiadny digitálny podpis</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1329"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Prosím, ídite do Štandardného centrála a povolte režim vývojára, potom skúste znovu. Pokračovať?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1332"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1333"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1280"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1394"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1983"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1284"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>Nepodarilo sa inštalovať %1: žiadny platný digitálny podpis</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1435"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Tento balíčok nemá platný digitálny podpis. Pokračovať s inštaláciou?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1437"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1438"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1278"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1391"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1980"/>
        <source>Unable to install</source>
        <translation>Nepodarilo sa inštalovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1392"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Tento balíčok nemá platný digitálny podpis</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="902"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="908"/>
        <source>Broken dependencies: %1</source>
        <translation>Zlomené závislosti: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="149"/>
        <source>Authentication failed</source>
        <translation>Autentifikácia neúspešná</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="834"/>
        <source>Unmatched package architecture</source>
        <translation>Nezabezpečená architektúra balíčkov</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="51"/>
        <source>Drag deb packages here</source>
        <translation>Pridajte balíčky deb sem</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="93"/>
        <source>Select File</source>
        <translation>Vybrať súbor</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Show details</source>
        <translation>Zobraziť podrobnosti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Zbaliť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="179"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Inštalovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="180"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="182"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Späť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="545"/>
        <source>Install %1 will remove: </source>
        <translation>Inštalácia %1 odstráni: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="563"/>
        <source>Dependencies in the repository</source>
        <translation>Závislosti v repozitári</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="570"/>
        <source>Missing dependencies</source>
        <translation>Chýbajúce závislosti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="629"/>
        <source>Installing dependencies: %1</source>
        <translation>Inštalácia závislostí: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="87"/>
        <source>Same version installed</source>
        <translation>Rovnaká verzia je nainštalovaná</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="91"/>
        <source>Earlier version installed: %1</source>
        <translation>Nainštalovaná skoršia verzia: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="96"/>
        <source>Later version installed: %1</source>
        <translation>Neskoršia verzia je nainštalovaná: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="102"/>
        <source>Unmatched package architecture</source>
        <translation>Nezabezpečená architektúra balíčkov</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Select all</source>
        <translation>Vybrať všetko</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="24"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Inštalovať</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="62"/>
        <source>Installing</source>
        <translation>Inštalujem</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="66"/>
        <source>Installed</source>
        <translation>Nainštalované</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
        <source>Failed</source>
        <translation>Neúspešné</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="70"/>
        <source>Waiting</source>
        <translation>Čakanie</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="246"/>
        <source>Same version installed</source>
        <translation>Rovnaká verzia je nainštalovaná</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="248"/>
        <source>Later version installed: %1</source>
        <translation>Neskoršia verzia je nainštalovaná: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
        <source>Earlier version installed: %1</source>
        <translation>Nainštalovaná skoršia verzia: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="189"/>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="52"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Zbaliť</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Základný</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Skontrolujte digitálne podpisy, ak je povolený režim vývojára</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="88"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>Ak chcete nainštalovať nepodpísané aplikácie, pôjdite do Bezpečnostného centra &gt; Nástroje &gt; Bezpečnosť aplikácie a vyberte typy aplikácií, ktoré môžete nainštalovať.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="90"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>Bezpečnostné centrum &gt; Nástroje &gt; Bezpečnosť aplikácie</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="54"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>Systém nemá nainštalované prostredie Linglong, prosím nainštalujte ho najskôr</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Unable to install</source>
        <translation>Nemôžem nainštalovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="49"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>Tento balíček nemá platný digitálny podpis a bol zablokovaný pri inštalácii/spustení. Pre zmenenie nastavení pôjdite do Bezpečnostného centra &gt; Nástroje &gt; Bezpečnosť aplikácie.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="52"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Zrušiť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="53"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="282"/>
        <source>Will remove: </source>
        <translation>Odstráni: </translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1035"/>
        <source>Collapse</source>
        <translation>Zbaliť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="519"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1233"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1438"/>
        <source>Reinstall</source>
        <translation>Reinštalovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1238"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1443"/>
        <source>Later version installed: %1</source>
        <translation>Neskoršia verzia je nainštalovaná: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1239"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1444"/>
        <source>Downgrade</source>
        <translation>Znížiť verziu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1244"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1449"/>
        <source>Earlier version installed: %1</source>
        <translation>Nainštalovaná skoršia verzia: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1336"/>
        <source>Installing dependencies: %1</source>
        <translation>Inštalácia závislostí: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1499"/>
        <source>Failed to install %1</source>
        <translation>Nepodarilo sa nainštalovať %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="244"/>
        <source>Version: </source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
        <source>Select a compatibility mode:</source>
        <translation>VybraŤ režim kompatibility:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="511"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Inštalovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="515"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="523"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="527"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Späť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="531"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="777"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="818"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>Skúša sa inštalovať %2 v režime kompatibility %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="858"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>Odstanovanie %2 z režimu kompatibility %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="987"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2 bol úspešne nainštalovaný do režimu kompatibility %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
        <source>Installed successfully</source>
        <translation>Úspešne nainštalované</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1000"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2 bol úspešne odinštalovaný v režime kompatibility s %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Uninstalled successfully</source>
        <translation>Úspešne odinštalované</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Uninstall Failed</source>
        <translation>Odinštalovanie zlyhalo</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1070"/>
        <source>Install %1 will remove: </source>
        <translation>Inštalácia %1 odstráni: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1091"/>
        <source>Dependencies in the repository</source>
        <translation>Závislosti v repozitári</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1098"/>
        <source>Missing dependencies</source>
        <translation>Chýbajúce závislosti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1245"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1450"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Aktualizovať</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1505"/>
        <source>Invalid digital signature</source>
        <translation>Neplatný digitálne podpis</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="232"/>
        <source>Name: </source>
        <translation>Názov:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1232"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1437"/>
        <source>Same version installed</source>
        <translation>Rovnaká verzia je nainštalovaná</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="762"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="984"/>
        <source>Show details</source>
        <translation>Zobraziť podrobnosti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Show dependencies</source>
        <translation>Zobraziť závislosti</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="843"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="997"/>
        <source>Show details</source>
        <translation>Zobraziť podrobnosti</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="557"/>
        <source>Installation Failed</source>
        <translation>Inštalácia zlyhala</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Show related packages</source>
        <translation>Zobraziť súvisiace balíčky</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Zbaliť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="41"/>
        <source>Confirm</source>
        <translation>Potvrdiť</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Naozaj chcete odinštalovať %1?
Všetky závislosti budú tiež odstránené</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="133"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>Naozaj chcete odinštalovať %1?
Systém alebo iné aplikácie môžu nefungovať správne</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="177"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>Naozaj chcete odinštalovať %2 
v režime kompatibility s %1?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>Správca balíčkov</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Aplikácia Deepin Správca balíčkov slúži na pomoc používateľom pri inštalácii a odstraňovaní lokálnych balíčkov, podporuje hromadnú inštaláciu.</translation>
    </message>
</context>
</TS>
